use std::net::SocketAddr;
use std::str::FromStr;
use std::sync::Arc;

pub type VaultRef = Arc<Vault>;

#[derive(Debug, Clone, PartialEq, Copy)]
pub struct Config {
    pub addr: SocketAddr,
}

impl Default for Config {
    fn default() -> Self {
        Self {
            addr: SocketAddr::from_str("127.0.0.1:1337").unwrap(),
        }
    }
}

#[derive(Debug, Clone, PartialEq)]
pub struct Vault {
    secret: String,
}

impl Vault {
    pub fn new(secret: &str) -> VaultRef {
        let v = Self {
            secret: secret.to_string(),
        };
        Arc::new(v)
    }
    pub fn secret(&self) -> &str {
        &self.secret
    }
}
